@@ -3,7 +3,7 @@ import argparse
 
 from . import releaselog
 
-__version__ = "0.1"
+__version__ = "0.2"
 
 
 def main():
@@ -17,9 +17,7 @@ def main():
         cwd = os.path.abspath(args['git_path'])
     latest_file = releaselog.build_release_page(cwd)
 
-    releaselog.update_full_release_notes(latest_file)
-
-    print "Release Notes file has been updated."
+    releaselog.update_full_release_notes(cwd, latest_file)
 
 
 def get_args():
