@@ -12,7 +12,9 @@ of taskotron.
 
 """
 
+FRAGMENT_HEADER = '**%s %s**\n'
+
 # This is the format string for log entries returned from
 # `git log --pretty=format:<foo>`
-FMT_STRING = '%s (`%h <http://phab.qadevel.cloud.fedoraproject\
+FMT_STRING = ' * %s (`%h <http://phab.qadevel.cloud.fedoraproject\
 .org/rLTRN%H>`_)%n'
